@@ -1,6 +1,6 @@
 package Data::Format::Pretty::Ruby;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -10,7 +10,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 sub format_pretty {
     my ($data, $opts) = @_;
@@ -21,16 +21,19 @@ sub format_pretty {
 1;
 # ABSTRACT: Pretty-print data structure as Ruby code
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Data::Format::Pretty::Ruby - Pretty-print data structure as Ruby code
 
 =head1 VERSION
 
-version 0.01
+This document describes version 0.02 of Data::Format::Pretty::Ruby (from Perl distribution Data-Format-Pretty-Ruby), released on 2015-02-11.
 
 =head1 SYNOPSIS
 
@@ -45,6 +48,8 @@ Some example output:
 
  { "a" => 1, "b" => 2 }
 
+=back
+
 =head1 DESCRIPTION
 
 This module uses L<Data::Dump::Ruby> to encode data as Ruby code.
@@ -60,20 +65,31 @@ options.
 
 L<Data::Format::Pretty>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Data-Format-Pretty-Ruby>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Data-Format-Pretty-Ruby>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Format-Pretty-Ruby>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
